import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.PriorityQueue;
import java.util.StringTokenizer;

public class Task3 {

	public static class Worker implements Comparable<Worker> {
		int a;
		int t;
		int num;

		public Worker(int t, int a, int num) {
			super();
			this.a = a;
			this.t = t;
			this.num = num;
		}

		@Override
		public int compareTo(Worker o2) {
			if (this.t == o2.t)
				return this.num - o2.num;
			return this.num - o2.num;
		}

	}

	public static class Lift {
		int a;
		ArrayList<Worker> inside;

		public Lift() {
			a = 0;
			inside = new ArrayList<Worker>();
		}
	}

	public static void main(String[] args) throws IOException {

		BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
		StringTokenizer st = new StringTokenizer(br.readLine());

		int n = Integer.parseInt(st.nextToken());
		int m = Integer.parseInt(st.nextToken());

		PriorityQueue<Worker> workers = new PriorityQueue<Worker>();

		for (int i = 0; i < n; i++) {
			st = new StringTokenizer(br.readLine());
			workers.add(new Worker(Integer.parseInt(st.nextToken()), Integer.parseInt(st.nextToken()) - 1, i + 1));
		}

		int time = 0;
		Lift lift = new Lift();
		int[] finishTimes = new int[n];
		Worker activeCall = null;
		Iterator<Worker> iter;
		Worker cur;

		ArrayList<ArrayList<Worker>> waiting = new ArrayList<ArrayList<Worker>>();
		waiting.ensureCapacity(m);
		for (int i = 0; i < m; i++) {
			waiting.add(i, new ArrayList<Worker>());
		}

		while (workers.size() > 0) {
			// update waiting workers
			iter = workers.iterator();
			while (iter.hasNext()) {
				cur = iter.next();
				if (cur.t == time) {
					waiting.get(cur.a).add(cur);
				}
			}

			// move lift down if people inside...
			if (lift.inside.size() > 0) {
				if (lift.a != 0)
					lift.a--;
			} else {
				// ...else move to existing active call
				if (activeCall != null) {
					lift.a++;
				}
			}

			// collect workers if possible
			if ((waiting.get(lift.a).size() > 0 && lift.inside.size() > 0)
					|| (activeCall != null && lift.a == activeCall.a)) {
				iter = waiting.get(lift.a).iterator();
				ArrayList<Worker> toRemove = new ArrayList<Worker>();
				while (iter.hasNext()) {
					cur = iter.next();
					toRemove.add(cur);
					lift.inside.add(cur);
				}
				iter = toRemove.iterator();
				while (iter.hasNext())
					waiting.get(lift.a).remove(iter.next());
				// flush activeCall
				activeCall = null;
			}

			// update workers.a
			iter = lift.inside.iterator();
			while (iter.hasNext()) {
				iter.next().a = lift.a;
			}

			// exit on first floor
			if (lift.a == 0 && lift.inside.size() > 0) {
				iter = lift.inside.iterator();
				ArrayList<Worker> toRemove = new ArrayList<Worker>();
				while (iter.hasNext()) {
					cur = iter.next();
					toRemove.add(cur);
					finishTimes[cur.num - 1] = time;
				}
				iter = toRemove.iterator();
				while (iter.hasNext()) {
					cur = iter.next();
					lift.inside.remove(cur);
					waiting.get(0).remove(cur);
					workers.remove(cur);
				}
			}

			// skip end if all workers exited
			if (workers.size() == 0) {
				continue;
			}

			// update active call if needed
			if (activeCall == null && lift.inside.size() == 0) {
				if (workers.peek().t <= time) {
					activeCall = workers.peek();
				}
			}

			time++;
		}

		for (int i = 0; i < n; i++) {
			System.out.println(finishTimes[i]);
		}

	}

}
